import { Node, NodePool } from '@jfrog-pipelines/data-access-layer';
import { AmqpPublisher } from '@jfrog-pipelines/amqp-client';
import { UnknownType } from '@jfrog-pipelines/types';
export declare enum NodeStatus {
    queued = 4000,
    processing = 4001,
    success = 4002,
    failure = 4003,
    waiting = 4005,
    cancelled = 4006,
    unstable = 4007,
    skipped = 4008,
    timeout = 4009,
    stopped = 4010,
    deleted = 4011,
    cached = 4012,
    cancelling = 4013,
    timingout = 4014
}
export declare const activeNodeStatus: NodeStatus[];
export declare const unhealthyNodeStatuses: NodeStatus[];
export declare const idleNodeStatuses: NodeStatus[];
export declare const nodeAccessorID = "1";
export declare enum NodeActions {
    CREATE = 10,
    CACHE = 20,
    START = 30,
    DELETE = 40
}
export declare type NodeCreateAttributes = {
    projectId: number;
    nodePoolId: number;
    friendlyName: string;
    isOnDemand: boolean;
    statusCode: number;
    statusLastUpdatedAt: Date;
    createdBy?: string;
    updatedBy?: string;
    stopRequested: boolean;
    intendedBuildPlaneVersion: string;
    projectIntegrationId: number;
    sshPort: number;
    sshUser: string;
    systemPropertyBag: UnknownType;
    initPropertyBag: UnknownType;
    isAutoInitialized: boolean;
    providerMetadataPropertyBag: {
        instanceSize: string;
        operatingSystem: string;
        uniqueToken: string;
    };
};
export declare class NodeService {
    private readonly publisher;
    private readonly logger;
    private readonly nodeDao;
    private readonly accessClient;
    constructor(publisher: AmqpPublisher);
    createNode(attribute: NodeCreateAttributes): Promise<Node>;
    getRunningNodes(poolID: number): Promise<Node[]>;
    getAllNodes(poolID: number): Promise<Node[]>;
    getOrphanNodes(): Promise<Node[]>;
    filterActiveNodes(nodes: Node[]): Node[];
    filterAvailableNodes(nodes: Node[]): Node[];
    filterIdleNodes(nodePool: NodePool, nodes: Node[]): Node[];
    filterCachedNodes(nodes: Node[]): Node[];
    applyNodeToStoppedState(node: Node): Promise<Node>;
    applyNodeToCachedState(node: Node): Promise<Node>;
    applyNodeWaitingState(node: Node): Promise<Node>;
    private isNodeIdle;
    private applyNodeState;
    private getNodeAccessToken;
    private updateNodeBootStrapToken;
    private sendWWWSignal;
}
